from enum import Enum

from sqlalchemy import Column, Integer, Text, BigInteger, String, SmallInteger, Boolean, TIMESTAMP
from sqlalchemy.orm import declarative_base

Base = declarative_base()

class ModuleAgentType(int, Enum):
    NATIVE = 0  # 原生Agent
    COZE = 1    # Coze Agent


class ServiceModule(Base):
    __tablename__ = "service_module"
    id = Column(BigInteger, primary_key=True, autoincrement=True, comment="主键id")
    name = Column(String(64), nullable=False, comment="唯一名称")
    display_name = Column(String(64), nullable=True, comment="显示名")
    default_agent_type = Column(SmallInteger, nullable=True, comment="默认Agent类型，0-原生，1-Coze")
    default_agent_id = Column(BigInteger, nullable=True, comment="默认Agent ID")
    is_delete = Column(Boolean, nullable=False, default=False, comment="逻辑删除标识")
    create_time = Column(TIMESTAMP, nullable=False, server_default="CURRENT_TIMESTAMP", comment="创建时间")
    update_time = Column(TIMESTAMP, nullable=False, server_default="CURRENT_TIMESTAMP", onupdate="CURRENT_TIMESTAMP", comment="更新时间")